emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master 7bf393dcf0: ; Consistently call alists "association list"


From: Stefan Kangas
Subject: master 7bf393dcf0: ; Consistently call alists "association list"
Date: Sun, 27 Nov 2022 12:13:05 -0500 (EST)

branch: master
commit 7bf393dcf0d905b947e5f5311815a08586ced0b0
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>

    ; Consistently call alists "association list"
    
    * doc/lispref/compile.texi (Compiler Errors):
    * doc/misc/gnus.texi (Score File Format):
    * etc/NEWS.24:
    * lisp/emacs-lisp/byte-run.el (with-suppressed-warnings):
    * lisp/progmodes/gdb-mi.el (gdb-threads-list)
    (gdb-breakpoints-list, gdb-place-breakpoints): Prefer the term
    "association list" for alists.
---
 doc/lispref/compile.texi    | 2 +-
 doc/misc/gnus.texi          | 2 +-
 etc/NEWS.24                 | 2 +-
 lisp/emacs-lisp/byte-run.el | 2 +-
 lisp/progmodes/gdb-mi.el    | 6 +++---
 5 files changed, 7 insertions(+), 7 deletions(-)

diff --git a/doc/lispref/compile.texi b/doc/lispref/compile.texi
index d1d281d709..3e39734999 100644
--- a/doc/lispref/compile.texi
+++ b/doc/lispref/compile.texi
@@ -516,7 +516,7 @@ using the @code{with-suppressed-warnings} macro:
 @defspec with-suppressed-warnings warnings body@dots{}
 In execution, this is equivalent to @code{(progn @var{body}...)}, but
 the compiler does not issue warnings for the specified conditions in
-@var{body}.  @var{warnings} is an associative list of warning symbols
+@var{body}.  @var{warnings} is an association list of warning symbols
 and function/variable symbols they apply to.  For instance, if you
 wish to call an obsolete function called @code{foo}, but want to
 suppress the compilation warning, say:
diff --git a/doc/misc/gnus.texi b/doc/misc/gnus.texi
index 10f7bd94f7..94c75ed30c 100644
--- a/doc/misc/gnus.texi
+++ b/doc/misc/gnus.texi
@@ -20564,7 +20564,7 @@ returned value is required to be an integer.
 (score-fn (custom-scoring))
 @end example
 
-The user-defined function is called with an associative list with the
+The user-defined function is called with an association list with the
 keys @code{number subject from date id refs chars lines xref extra}
 followed by the article's score before the function is run.
 
diff --git a/etc/NEWS.24 b/etc/NEWS.24
index 8ef479ac0a..31e48f9aca 100644
--- a/etc/NEWS.24
+++ b/etc/NEWS.24
@@ -704,7 +704,7 @@ related to that keyword.
 
 *** The format of 'archive-contents' files, generated by package
 repositories, has changed to allow a new (fifth) element in the data
-vectors, containing an associative list with extra properties.
+vectors, containing an association list with extra properties.
 (For example, 'describe-package' uses the ':url' extra property to
 display a "Homepage" header.)
 
diff --git a/lisp/emacs-lisp/byte-run.el b/lisp/emacs-lisp/byte-run.el
index a33808ab92..1babf3ec2c 100644
--- a/lisp/emacs-lisp/byte-run.el
+++ b/lisp/emacs-lisp/byte-run.el
@@ -632,7 +632,7 @@ enabled."
 (defmacro with-suppressed-warnings (warnings &rest body)
   "Like `progn', but prevents compiler WARNINGS in BODY.
 
-WARNINGS is an associative list where the first element of each
+WARNINGS is an association list where the first element of each
 item is a warning type, and the rest of the elements in each item
 are symbols they apply to.  For instance, if you want to suppress
 byte compilation warnings about the two obsolete functions `foo'
diff --git a/lisp/progmodes/gdb-mi.el b/lisp/progmodes/gdb-mi.el
index dff677e785..e8d8f9104e 100644
--- a/lisp/progmodes/gdb-mi.el
+++ b/lisp/progmodes/gdb-mi.el
@@ -177,7 +177,7 @@ May be manually changed by user with `gdb-select-frame'.")
   "Number of selected line for main current thread.")
 
 (defvar gdb-threads-list nil
-  "Associative list of threads provided by \"-thread-info\" MI command.
+  "Association list of threads provided by \"-thread-info\" MI command.
 
 Keys are thread numbers (in strings) and values are structures as
 returned from -thread-info by `gdb-mi--partial-output'.  Updated in
@@ -196,7 +196,7 @@ Updated in `gdb-thread-list-handler-custom'.")
 See also `gdb-running-threads-count'.")
 
 (defvar gdb-breakpoints-list nil
-  "Associative list of breakpoints provided by \"-break-list\" MI command.
+  "Association list of breakpoints provided by \"-break-list\" MI command.
 
 Keys are breakpoint numbers (in string) and values are structures
 as returned from \"-break-list\" by `gdb-mi--partial-output'
@@ -3159,7 +3159,7 @@ See `def-gdb-auto-update-handler'."
           (gdb-remove-breakpoint-icons (point-min) (point-max)))))
   (dolist (breakpoint gdb-breakpoints-list)
     (let* ((breakpoint (cdr breakpoint)) ; gdb-breakpoints-list is
                                         ; an associative list
            (line (gdb-mi--field breakpoint 'line)))
       (when line
         (let ((file (gdb-mi--field breakpoint 'fullname))
@@ -3159,7 +3159,7 @@ See `def-gdb-auto-update-handler'."
   (dolist (breakpoint gdb-breakpoints-list)
     (let* ((breakpoint (cdr breakpoint)) ; gdb-breakpoints-list is
-                                        ; an associative list
+                                        ; an association list
            (line (gdb-mi--field breakpoint 'line)))
       (when line



reply via email to

[Prev in Thread] Current Thread [Next in Thread]